modules
=======

.. toctree::
   :titlesonly:
   :hidden:
   :maxdepth: 2

   amda/amda
   sscweb/sscweb
   cdaweb/cdaweb


Speasy provides access to the following Web Services:

    - :doc:`AMDA <amda/amda>`
    - :doc:`SSCWeb <sscweb/sscweb>`
    - :doc:`CDAWeb <cdaweb/cdaweb>`

While you can download any data with :meth:`speasy.get_data`, each web service have specificities and might expose extra
features through their dedicated modules.
